# zprocess

[![Build Status](https://travis-ci.com/chrisjbillington/zprocess.svg?branch=master)](https://travis-ci.com/chrisjbillington/zprocess)

[![codecov](https://codecov.io/gh/chrisjbillington/zprocess/branch/master/graph/badge.svg)](https://codecov.io/gh/chrisjbillington/zprocess)

A set of utilities for multiprocessing using
zeromq. Includes process creation and management, output
redirection, message passing, inter-process locks, logging,
and a process-tree-wide event system.

( 
[view on pypi](https://pypi.python.org/pypi/zprocess/);
[view on Github](https://github.com/chrisjbillington/zprocess)
)

   * Install `python setup.py install`.

